@@ -38,6 +38,7 @@ namespace bareFTP.Gui.FileManager
 		
 		public event System.EventHandler DownloadRequest;
 		public event System.EventHandler UploadRequest;
+		public event System.EventHandler DirChanged;
 		
 		public new bool HasFocus
 		{
@@ -77,7 +78,7 @@ namespace bareFTP.Gui.FileManager
 				w45.Pixbuf = Gtk.IconTheme.Default.LoadIcon("stock_new-dir", 16, 0);
 			else
 				w45.Pixbuf = Gtk.IconTheme.Default.LoadIcon(Gtk.Stock.Directory, 16, 0);
-			w45.TooltipText = Catalog.GetString("Create New Diretory");
+			w45.TooltipText = Catalog.GetString("New Directory");
 			
             btnnewfolder.Add(w45);
             btnnewfolder.Label = null;
@@ -222,9 +223,58 @@ namespace bareFTP.Gui.FileManager
 			if(args.OldName != args.NewName)
 			{
 				if(Mono.Unix.UnixFileInfo.GetFileSystemEntry(System.IO.Path.Combine(this.cwd.LocalPath, args.OldName)).IsDirectory)
-					System.IO.Directory.Move(System.IO.Path.Combine(this.cwd.LocalPath, args.OldName), System.IO.Path.Combine(this.cwd.LocalPath, args.NewName));
+				{
+					if(System.IO.Directory.Exists(System.IO.Path.Combine(this.cwd.LocalPath, args.NewName)))
+					{
+						MessageDialog md = new MessageDialog(null, DialogFlags.DestroyWithParent, 
+				                                      MessageType.Error, ButtonsType.Ok,
+				                                      string.Format(Catalog.GetString("A directory named {0} already exists") ,args.NewName));
+						md.Run ();
+				md.Destroy();
+						
+					}
+					else
+					{
+						try
+						{
+							System.IO.Directory.Move(System.IO.Path.Combine(this.cwd.LocalPath, args.OldName), System.IO.Path.Combine(this.cwd.LocalPath, args.NewName));
+						}
+						catch(Exception ex)
+						{
+							MessageDialog md = new MessageDialog(null, DialogFlags.DestroyWithParent, 
+				                                      MessageType.Error, ButtonsType.Ok,
+				                                      ex.Message);
+							md.Run ();
+							md.Destroy();
+						}
+					}
+				}
 				else
-					System.IO.Directory.Move(System.IO.Path.Combine(this.cwd.LocalPath, args.OldName), System.IO.Path.Combine(this.cwd.LocalPath, args.NewName));
+				{
+					if(System.IO.File.Exists(System.IO.Path.Combine(this.cwd.LocalPath, args.NewName)))
+					{
+						MessageDialog md = new MessageDialog(null, DialogFlags.DestroyWithParent, 
+				                                      MessageType.Error, ButtonsType.Ok,
+				                                      string.Format(Catalog.GetString("A file named {0} already exists") ,args.NewName));
+						md.Run ();
+						md.Destroy();
+					}
+					else
+					{
+						try
+						{
+							System.IO.Directory.Move(System.IO.Path.Combine(this.cwd.LocalPath, args.OldName), System.IO.Path.Combine(this.cwd.LocalPath, args.NewName));
+						}
+						catch(Exception ex)
+						{
+							MessageDialog md = new MessageDialog(null, DialogFlags.DestroyWithParent, 
+				                                      MessageType.Error, ButtonsType.Ok,
+				                                      ex.Message);
+							md.Run ();
+							md.Destroy();
+						}
+					}
+				}
 			}
     		ChangeDir(cwd.LocalPath);
     	}
@@ -282,6 +332,19 @@ namespace bareFTP.Gui.FileManager
 		protected void OnDirChanged(DirectoryChangedArgs args)
 		{
 			ChangeDir(args.NewPath);
+			if(DirChanged != null)
+				DirChanged.Invoke(args.NewPath, null);
+		}
+		
+		public bool ChangeDirSynchronized(string nPath)
+		{
+			if(filelist.DirectoryExisist(nPath))
+			{
+				ChangeDir(nPath);
+				return true;
+			}
+			else
+				return false;
 		}
 		
 		protected void OnFileDelete(FileListActionArgs args)
@@ -316,9 +379,12 @@ namespace bareFTP.Gui.FileManager
 		{
 			filelist.MakeDir(Catalog.GetString("New Directory"), true);
 		}
+		
 		protected void DirUpClicked(object o, EventArgs args)
 		{
 			ChangeDir(GetPreviousDir());
+			if(DirChanged != null)
+				DirChanged.Invoke("..", null);
 		}
 		
 		private string GetPreviousDir()
@@ -422,25 +488,49 @@ namespace bareFTP.Gui.FileManager
 		{
 			try
 			{
-				Gtk.ListStore store = new Gtk.ListStore (typeof (FileTreeNode));
+				FileTreeNode lnode = null;
+				
+				Gtk.ListStore store = new Gtk.ListStore (
+				                                         typeof (FileTreeNode),
+				                                         typeof (Gdk.Pixbuf),
+				                                         typeof(string),
+				                                         typeof(string),
+				                                         typeof(string),
+				                                         typeof(string),
+				                                         typeof(string),
+				                                         typeof(string));
+				
 				List<string> entries = new List<string>(System.IO.Directory.GetFileSystemEntries(data.FullName));
 				
+				
 				bool showHidden;
 				if(!string.IsNullOrEmpty(showhiddenstr))
 					showHidden = bool.Parse(showhiddenstr);
 				else
 					showHidden = filelist.ShowHiddenFiles;
+				lnode = new FileTreeNode("..", -1, DateTime.MaxValue, string.Empty, string.Empty, string.Empty, true, false, string.Empty);
 				
-				store.AppendValues(new FileTreeNode("..", -1, DateTime.MaxValue, string.Empty, string.Empty, string.Empty, true, false, string.Empty));
+				store.AppendValues(lnode, lnode.Type, lnode.FileName, string.Empty, string.Empty, string.Empty, string.Empty, string.Empty);
 
 				foreach(string entry in entries)
 				{
 					Mono.Unix.UnixFileInfo fi = new Mono.Unix.UnixFileInfo(System.IO.Path.Combine(data.FullName, entry));
+					
 					if(showHidden || (!showHidden && !fi.Name.StartsWith(".")))
 					{
 						try
 						{
-							store.AppendValues(new FileTreeNode(fi.Name, fi.Length, fi.LastWriteTime, GetUserLabel(fi.OwnerUserId), GetGroupLabel(fi.OwnerGroupId), PermissionParser.UFAPToRWX(fi.FileAccessPermissions), fi.IsDirectory, fi.IsSymbolicLink, string.Empty));
+							string str_size = string.Empty;
+							string str_date = string.Empty;
+							
+							lnode = new FileTreeNode(fi.Name, fi.Length, fi.LastWriteTime, GetUserLabel(fi.OwnerUserId), GetGroupLabel(fi.OwnerGroupId), PermissionParser.UFAPToRWX(fi.FileAccessPermissions), fi.IsDirectory, fi.IsSymbolicLink, string.Empty);
+							
+							if(!lnode.IsDir)
+								str_size = Gnome.Vfs.Format.FileSizeForDisplay(fi.Length);
+							if(lnode.Date < DateTime.MaxValue)
+								str_date = lnode.Date.ToString("r");
+							
+							store.AppendValues(lnode, lnode.Type, lnode.FileName, str_size, str_date, lnode.User, lnode.Group, lnode.Rights);
 						}
 						catch {}
 					}
