@@ -45,6 +45,8 @@ namespace bareFTP.Gui.FileManager
 		public event System.EventHandler DownloadRequest;
 		public event System.EventHandler UserAction;
 		public event System.EventHandler StatusBarMessage;
+		public event System.EventHandler DirChanged;
+		
 		public event ExternalUploadRequestHandler ExternalUploadRequest;
 		
 		private System.Threading.EventWaitHandle ewh;
@@ -52,6 +54,8 @@ namespace bareFTP.Gui.FileManager
 		private Button btnup;
 		private Button btnnewfolder;
 		private string showhiddenstr;
+		private bool disabled = false;
+		private bareFTP.Preferences.Config config;
 		
 		public new bool HasFocus
 		{
@@ -60,6 +64,7 @@ namespace bareFTP.Gui.FileManager
 		
 		public FileManagerRemote(bareFTP.Preferences.Config config, Gui.ActivityProgressBar progressBar) : base(false, 1)
 		{
+			this.config = config;
 			
 			ewh = new System.Threading.EventWaitHandle(false, System.Threading.EventResetMode.AutoReset);
 			progress = progressBar;
@@ -90,7 +95,7 @@ namespace bareFTP.Gui.FileManager
 				w45.Pixbuf = Gtk.IconTheme.Default.LoadIcon("stock_new-dir", 16, 0);
 			else
 				w45.Pixbuf = Gtk.IconTheme.Default.LoadIcon(Gtk.Stock.Directory, 16, 0);
-			w45.TooltipText = Catalog.GetString("Create New Diretory");
+			w45.TooltipText = Catalog.GetString("New Directory");
             btnnewfolder.Add(w45);
             btnnewfolder.Label = null;
 			btnnewfolder.Relief = ReliefStyle.None;
@@ -138,7 +143,6 @@ namespace bareFTP.Gui.FileManager
 			pathEntry.Sensitive = false;
 			
 			this.PackStart(scrollw);
-			
 		}
 
 		void HandleFilelistSendCommandRequested (object sender, EventArgs e)
@@ -202,7 +206,7 @@ namespace bareFTP.Gui.FileManager
 		
 		protected void OnDeleteRequest(FileListActionArgs args)
 		{
-			if(!bareFTP.Gui.Dialog.Dialogs.QuestionDialog(Catalog.GetString("Are you sure you want to delete the selected files or directories?")))
+			if(!bareFTP.Gui.Dialog.Dialogs.QuestionDialog(Catalog.GetString("Are you sure you want to delete the selected files?")))
 				return;
 
 			System.Threading.Thread t = new System.Threading.Thread(DoDelete);
@@ -234,12 +238,27 @@ namespace bareFTP.Gui.FileManager
 			ChangeDir(nPath, usecache, false, false);
 		}
 		
+		public bool ChangeDirSynchronized(string nPath)
+		{
+			if(filelist.DirectoryExisist(nPath))
+			{
+				ChangeDir(nPath, true, true, false);
+				return true;
+			}
+			else
+				return false;
+		}
+		
 		public void ChangeDir(string nPath, bool usecache, bool internalCall, bool previousdir)
 		{
 			ChangeDirParams cdp = new ChangeDirParams();
 			cdp.internalCall = internalCall;
 			cdp.nPath = nPath;
-			cdp.usecache = usecache;
+			if(config.General_EnableDirectoryCache)
+				cdp.usecache = usecache;
+			else
+				cdp.usecache = false;
+			
 			cdp.previousdir = previousdir;
 			
 			Thread t = new Thread(new ParameterizedThreadStart(DoChangeDir));
@@ -253,6 +272,7 @@ namespace bareFTP.Gui.FileManager
 			this.conn = conn;
 			filelist.ProtocolType = conn.Protocol;
 			IsConnected = true;
+			
 			cache = new FileListCache(180);
 			ChangeDir(startDir, false);
 		}
@@ -269,6 +289,8 @@ namespace bareFTP.Gui.FileManager
 		protected void OnDirChanged(DirectoryChangedArgs args)
 		{
 		   ChangeDir(args.NewPath, !string.IsNullOrEmpty(args.NewPath), false, args.NewPath.EndsWith(".."));
+			if(DirChanged != null)
+				DirChanged.Invoke(args.NewPath, null);
 		}
 		
 		protected void OnLinkActivated(DirectoryChangedArgs args)
@@ -301,6 +323,8 @@ namespace bareFTP.Gui.FileManager
 				return;
 
 			ChangeDir(cwd.RemoveElementRemote(), true, false, true);
+			if(DirChanged != null)
+				DirChanged.Invoke("..", null);
 
 		}
 		
@@ -318,7 +342,16 @@ namespace bareFTP.Gui.FileManager
 		private Gtk.ListStore MakeNodeStore(List<RemoteFile> filelist)
 		{
 			
-			Gtk.ListStore store = new Gtk.ListStore (typeof (FileTreeNode));
+			//Gtk.ListStore store = new Gtk.ListStore (typeof (FileTreeNode));
+			Gtk.ListStore store = new Gtk.ListStore(typeof(FileTreeNode),
+			                                        typeof(Gdk.Pixbuf),
+			                                        typeof(string),
+				                                    typeof(string),
+				                                    typeof(string),
+				                                    typeof(string),
+				                                    typeof(string),
+				                                    typeof(string));
+			
 			bool showHidden;
 			if(!string.IsNullOrEmpty(showhiddenstr))
 				showHidden = bool.Parse(showhiddenstr);
@@ -327,13 +360,23 @@ namespace bareFTP.Gui.FileManager
 			
 			foreach(RemoteFile rfile in filelist)
 			{
-				
 				if(rfile.Filename != ".")
 				{
 					if(showHidden || rfile.Filename == ".." || (!showHidden && !rfile.Filename.StartsWith(".")))
-							store.AppendValues (new FileTreeNode(rfile));
+					{
+						FileTreeNode rnode = new FileTreeNode(rfile);
+						
+						string str_size = string.Empty;
+						string str_date = string.Empty;
+						
+						if(!rnode.IsDir)
+							str_size = Gnome.Vfs.Format.FileSizeForDisplay(rnode.Size);
+						if(rnode.Date < DateTime.MaxValue)
+							str_date = rnode.Date.ToString("r");
+						
+						store.AppendValues (rnode, rnode.Type, rnode.FileName, str_size, str_date, rnode.User, rnode.Group, rnode.Rights);
+					}
 				}
-				
 			}
 			
 			currentDirFileList = filelist;
@@ -344,14 +387,20 @@ namespace bareFTP.Gui.FileManager
 		{
 			get 
 			{
-				Disable();
+				bool handledisabling = true;
+				if(!disabled)
+					Disable();
+				else
+					handledisabling = false;
+				
 				List<RemoteFile> paths = new List<RemoteFile>();
          		
 				Thread t = new Thread(new ParameterizedThreadStart(DoTraverse));
 				t.Start(paths);
 				ewh.WaitOne();
 				conn.SetCurrentDirectory(cwd.RemotePath);
-				Enable();
+				if(handledisabling)
+					Enable();
 				return paths;
 			}
 		}
@@ -423,7 +472,7 @@ namespace bareFTP.Gui.FileManager
 				
 				foreach(FileTreeNode item in filelist.SelectedFileNodes)
 				{
-					Gnome.Vfs.Uri uri = new Gnome.Vfs.Uri(conn.Protocol.ToString().ToLower() + "://" + cwd.ToString(true) + "/" + item.FileName);
+					Gnome.Vfs.Uri uri = new Gnome.Vfs.Uri(conn.Protocol.ToString().ToLower() + "://" + System.Web.HttpUtility.UrlEncode(cwd.ToString(true)) + "/" + System.Web.HttpUtility.UrlEncode(item.FileName));
 					uri.HostName = conn.ConnProperties.Hostname;
 					uri.UserName = conn.ConnProperties.User;
 					str += uri.ToString() +  "\n";
@@ -456,12 +505,11 @@ namespace bareFTP.Gui.FileManager
 			
 			if(args.Info == 1)
 			{
-				
 				List<string> lfiles = new List<string>();
 				foreach(string s in files.Split(Environment.NewLine.ToCharArray()))
 				{
 					if(!string.IsNullOrEmpty(s.Trim()) && s.StartsWith("file://"))
-						lfiles.Add(s.Substring(7).Trim());
+						lfiles.Add(System.Web.HttpUtility.UrlDecode(s.Substring(7).Trim()));
 				}
 				
 				ExternalUploadRequest(lfiles, node);
@@ -478,7 +526,6 @@ namespace bareFTP.Gui.FileManager
 			set { showhiddenstr = value;}	
 		}
 		
-		
 		///////////THREADED REMOTE ACTIONS//////////////
 		
 		private void DoTraverse(object obj)
@@ -519,12 +566,22 @@ namespace bareFTP.Gui.FileManager
 		
 		private void DoChangeDir(object obj)
 		{
-			Disable();
+			bool handledisabling = true;
+			
+			if(!disabled)
+				Disable();
+			else
+				handledisabling = false;
+			
 			
 			ChangeDirParams cdp = obj as ChangeDirParams;
 			bool internalCall = cdp.internalCall;
 			string nPath = cdp.nPath;
 			bool usecache = cdp.usecache;
+			
+			if(!config.General_EnableDirectoryCache)
+				usecache = false;
+			
 			bool foundcachedstore = false;
 			
 			if(!internalCall)
@@ -603,7 +660,8 @@ namespace bareFTP.Gui.FileManager
 				
 				// Add a directory listing entry in cache
 				string newpath = cwd.ToString(true);
-				cache.AddEntry(newpath, store);
+				if(config.General_EnableDirectoryCache)
+					cache.AddEntry(newpath, store);
 				
 				// Add a treepath entry in cache (for remembering where you came from)
 				if(!cdp.previousdir && filelist.Selection.GetSelectedRows().Length == 1)
@@ -632,20 +690,25 @@ namespace bareFTP.Gui.FileManager
 			}
 			finally
 			{
-				Enable();
+				if(handledisabling)
+					Enable();
 			}
 		}
 		
 		private void DoDelete()
 		{
 			UserAction(null,null);
+			bool handledisabling = true;
 			
-			Disable();
+			if(!disabled)
+				Disable();
+			else
+				handledisabling = false;
 
 			try
 			{
 				if(StatusBarMessage != null)
-					StatusBarMessage(null, new StatusBarMessageArgs("Getting file and directory list..", false));
+					StatusBarMessage(null, new StatusBarMessageArgs(Mono.Unix.Catalog.GetString("Retrieving directory contents.."), false));
 				List<RemoteFile> rfiles = SelectedFileTree;
 				
 				if(rfiles != null)
@@ -654,7 +717,7 @@ namespace bareFTP.Gui.FileManager
 					rfiles.Reverse();
 
 					if(StatusBarMessage != null)
-						StatusBarMessage(null, new StatusBarMessageArgs("Deleting..", false));
+						StatusBarMessage(null, new StatusBarMessageArgs(Mono.Unix.Catalog.GetString("Deleting.."), false));
 					
 					foreach(RemoteFile file in rfiles)
 					{
@@ -689,7 +752,8 @@ namespace bareFTP.Gui.FileManager
 			}
 			finally
 			{
-				Enable();
+				if(handledisabling)
+					Enable();
 				ChangeDir(cwd.ToString(true), false, true, false);
 			}
 		}
@@ -697,6 +761,7 @@ namespace bareFTP.Gui.FileManager
 		public void Disable()
 		{
 			Gtk.Application.Invoke(delegate {
+					disabled = true;
 					progress.Start();
 					filelist.EventsDisabled = true;
 					pathEntry.Sensitive = false;
@@ -708,6 +773,7 @@ namespace bareFTP.Gui.FileManager
 		public void Enable()
 		{
 			Gtk.Application.Invoke(delegate {
+					disabled = false;
 					progress.Stop();
 					filelist.EventsDisabled = false;
 					pathEntry.Sensitive = true;
