@@ -52,6 +52,8 @@ namespace bareFTP.Gui.Preferences
 			cb_preservepermissions.Active = prefs.General_PreserveFilePermissions;
 			entryRemoteCharset.Changed += on_entry_charset_changed;
 			cb_showhiddenfiles.Toggled += on_show_hidden_toggled;
+			cb_enablecache.Active = prefs.General_EnableDirectoryCache;
+			cb_enablecache.Toggled += on_enable_cache_toggled;
 			cb_preservepermissions.Toggled += on_preserve_toggled;
 			btn_message_font.FontSet += on_font_set;
 			cb_use_gnome_keyring.Active = prefs.General_UseGnomeKeyring;
@@ -122,6 +124,10 @@ namespace bareFTP.Gui.Preferences
 		{
 			prefs.General_ShowHiddenFiles = cb_showhiddenfiles.Active; 
 		}
+		protected void on_enable_cache_toggled(object sender, EventArgs e)
+		{
+			prefs.General_EnableDirectoryCache = cb_enablecache.Active; 
+		}
 		protected void on_preserve_toggled(object sender, EventArgs e)
 		{
 			prefs.General_PreserveFilePermissions = cb_preservepermissions.Active;
