@@ -143,7 +143,7 @@ namespace bareFTP.Protocol.Sftp
 			
 			pty = bareFTP.SftpPty.PseudoTerminal.Open (null,
 					       conf.SSHProgramPath,
-					       new string [] {conf.SSHProgramPath, hostname, "-l", user, "-p", port.ToString(), "-e", "none", "-s", "sftp" },
+					       new string [] {conf.SSHProgramPath, hostname, "-e", "none", "-l", user, "-p", port.ToString(), "-s", "sftp" },
 					       null);
 			
 			consoleReader = new UnixStream (pty.FileDescriptor, false);
@@ -168,7 +168,7 @@ namespace bareFTP.Protocol.Sftp
 					{
 						terminalStr = System.Text.Encoding.ASCII.GetString(b).Trim();
 						
-						if(terminalStr.ToLower().IndexOf("yes/no") > 0)
+						if(terminalStr.ToLower().Contains("yes/no"))
 						{
 							
 							bool ans = false;
@@ -185,15 +185,15 @@ namespace bareFTP.Protocol.Sftp
 							}
 							else
 							{
-								if(terminalStr.IndexOf("Yes/No") > 0)
+								if(terminalStr.Contains("Yes/No"))
 									consoleWriter.Write("Yes\n");
-								if(terminalStr.IndexOf("yes/no") > 0)
+								if(terminalStr.Contains("yes/no"))
 									consoleWriter.Write("yes\n");
 								consoleWriter.Flush();
 								continue;
 							}
 						}
-						else if(terminalStr.ToLower().IndexOf("password") > 0)
+						else if(terminalStr.ToLower().Contains("password"))
 						{
 							if(!firsttry)
 							{
