@@ -40,21 +40,37 @@ namespace bareFTP
 			WidthRequest = 300;
 			//Name = "bareFTP";
 			ProgramName = "bareFTP"; // Requires Gtk# 2.12
-			Copyright = "Copyright \xa9 2007-2009 Christian Eide\n\n";
-			Authors = new string[] {"Christian Eide <christian@bareftp.org>"};
+			Copyright = "Copyright \xa9 2007-2010 Christian Eide\n\n";
+			Authors = new string[] {"Christian Eide <christian@eide-itc.no>"};
 			Logo = Gdk.Pixbuf.LoadFromResource("bareFTP.bareftp.png");
 			Website = "http://www.bareftp.org";
 			Comments = Mono.Unix.Catalog.GetString("File Transfer Client");
 			Artists = new string[] {"bareFTP icon by Kalle Persson <kalle@nemus.se>"};
-			TranslatorCredits = @"Catalan (ca): Sergi Mansilla <sergi.mansilla@gmail.com>
-German (de): Daniel Päßler <daniel@paessler.org>
-Spanish (es): Julio Napurí Carlos <julionc@gmail.com>
-French (fr): Simon Leblanc <contact@leblanc-simon.eu>
-Italian (it) Gianvito Cavasoli <gianvito@gmx.it>
-Norwegian (nb): Christian Eide <christian@bareftp.org>
-Polish (pl): Filip Chabik <hadret@gmail.com>
-Portuguese Brazilian (pt_BR): Alexandre Cavedon <alexandre.cavedon@gmail.com>
-Swedish (sv): Niclas Kroon <niclas.kroon@gmail.com>
+			TranslatorCredits = @"Catalan (ca): 
+	Sergi Mansilla <sergi.mansilla@gmail.com>
+	Innocent De Marchi <tangram.peces@gmail.com>
+German (de):
+	Daniel Päßler <daniel@paessler.org>
+Spanish (es): 
+	Julio Napurí Carlos <julionc@gmail.com>
+	Ricardo A. Hermosilla Carrillo <ra.hermosillac@gmail.com>
+	Innocent De Marchi <tangram.peces@gmail.com>
+French (fr): 
+	Simon Leblanc <contact@leblanc-simon.eu>
+Italian (it): 
+	Gianvito Cavasoli <gianvito@gmx.it>
+Norwegian Bokmål (nb): 
+	Christian Eide <christian@eide-itc.no>
+Polish (pl): 
+	Filip Chabik <hadret@gmail.com>
+Portuguese Brazilian (pt_BR): 
+	Alexandre Cavedon <alexandre.cavedon@gmail.com>
+Russian (ru): 
+	Алекс <davian818@gmail.com>
+Slovak (sk):
+	Peter Smrčák <smrcak@zymbo.sk>
+Swedish (sv): 
+	Niclas Kroon <niclas.kroon@gmail.com>
 ";
 		}
 		
